mcmc objects. You can select
iterations using the first dimension and variables using the second
dimension. Selecting iterations will return a vector or matrix, not an
mcmc object. If you want to do row-subsetting of an mcmc
object and preserve its dimensions, use the window function. Subsetting applied to an mcmc.list object will simultaneously
affect all the parallel chains in the object.
x[i,j]mcmc object[,
window.mcmc