read.coda reads Markov Chain Monte Carlo output in
the CODA format produced by OpenBUGS and JAGS. By default, all
of the data in the file is read, but the arguments start,
end and thin may be used to read a subset of the
data. If the arguments given to start, end or
thin are incompatible with the data, they are ignored.read.coda(output.file, index.file, start, end, thin, quiet=FALSE)
read.jags(file = "jags.out", start, end, thin, quiet=FALSE)mcmc containing a representation of
the data in the file.mcmc,
read.coda.interactive,
read.openbugs.