Learn R Programming

coda (version 0.16-1)

read.yesno: Read logical values from the command line

Description

This is a utility function for interactively reading a logical value from the command line.

The prompt string is printed, along a hint about the default answer. Answers "yes", "YES", "no", "NO" or any partial match are accepted. If the user enters a blank line, the default value is returned.

Usage

read.yesno(string, default=TRUE)

Arguments

string
A string to prompt the user with
default
Logical value giving the default answer

Value

  • A single logical value.