Learn R Programming

coda (version 0.16-1)

set.mfrow: Set layout for graphical plots

Description

This utility function is used by plotting functions in the coda package to determine the default layout, unless overriden by the user.layout option.

Usage

set.mfrow (Nchains = 1, Nparms = 1, nplots = 1, sepplot = FALSE)

Arguments

Nchains
Number of chains to plot
Nparms
Number of variables in each chain
nplots
Number of plots to produce
sepplot
Logical value controlling whether separate plots are created for each chain